# Table of Contents

- [technology-standards-management-capabilities](<./technology-standards-management-capabilities.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Technology Standards Management Capabilities](<./Technology-Standards-Management-Capabilities.md>)
  - [Introduction](<./Technology-Standards-Management-Capabilities/Introduction.md>)
  - [Technology Standards Management Capabilities](<./Technology-Standards-Management-Capabilities/Technology-Standards-Management-Capabilities.md>)
  - [Getting Started](<./Technology-Standards-Management-Capabilities/Getting-Started.md>)
  - [Was this page helpful?](<./Technology-Standards-Management-Capabilities/Was-this-page-helpful.md>)
